@@ -1,4 +1,3 @@
-
 import os.path
 import os
 import subprocess
@@ -573,12 +572,12 @@ def get_hvac_client(hvac_url: str = hvac_url,
             print(f"Something is missing, cannot authentificate.")
             raise ValueError
     except ConnectionError as e:
-        print(f"Connection error. Probably, you don't have correct certificates/chain for {hvac_url}."
-              f"Certificates are located at {certifi.where()}"
-              f"You can also use REQUESTS_CA_BUNDLE env variable to point to correct certs."
-              f"Full error: {str(e)}"
-              f"Also, if you are some kind of naughty boy/girl/whatever you can pass verify=False as one of the args"
-              f"Which is, obviously, very bad. Added it just for testing.")
+        print(f"Connection error. Probably, you don't have correct certificates/chain for {hvac_url}.\n"
+              f"Certificates are located at {certifi.where()}\n"
+              f"You can also use REQUESTS_CA_BUNDLE env variable to point to correct certs.\n"
+              f"Full error: {str(e)}\n"
+              f"Also, if you are some kind of naughty boy/girl/whatever you can pass verify=False as one of the args\n"
+              f"Which is, obviously, very bad. Added it just for testing.\n")
         return
     return client
 
